// created by Maria Isabel Santana
//created on: 05.07.2023

*****************APPENDIX TABLES: 11, 12, 13*****************





global omega=-0.01

use "$WORKING_ANALYSIS\games_time_and_risk_longS.dta", clear


gen Pchoice=.
gen PTchoice=.
gen timeln=.

************************************************************************************************************************************************************************************************************************************

xtset subid


** define outside consumption
	local omega = -0.01

** generate variables for estimation
	gen depvar = ln((time - `omega') / ((1+interest_time)*(150-time) - `omega'))

	gen ln_1_r = ln(1+interest_time)

** treatment dummies
	gen no_check = 1-check

** generate limits for tobit

	gen lower_limit =     ln((0-   `omega')/((1+interest_time)*150- `omega'))*0.9999 if interest_time <3
	replace lower_limit = ln((50-  `omega')/((1+interest_time)*100- `omega'))*0.9999 if interest_time==3
	replace lower_limit = ln((100- `omega')/((1+interest_time)*50-  `omega'))*0.9999 if interest_time==7
	replace lower_limit = ln((140- `omega')/((1+interest_time)*10-  `omega'))*0.9999 if interest_time==39

	gen upper_limit = ln((150- `omega')/((1+interest_time)*0- `omega'))






gen back_cons_mod=back_cons
replace back_cons_mod=back_cons_hh/hh_size if back_cons==0
sum back_cons_mod

gen back_cons_mod2=back_cons
replace back_cons_mod2=back_cons_hh/hh_size if back_cons<back_cons_hh

gen back_cons_mod_daily=back_cons_mod/7



******************************************************************
******************************************************************
** AVERAGE DAILY CONSUMPTION AS THE BACKGROUND CONSUMPTION
******************************************************************
******************************************************************

	

* define outside consumption
	sum back_cons_mod_daily
		local omegabc2 = -r(mean)
		di `omegabc2'

** generate variables for estimation
	gen depvar3 = ln((time - `omegabc2') / ((1+interest_time)*(150-time) - `omegabc2'))

** generate limits for tobit


	gen lower_limit3 =     ln((0-   `omegabc2')/((1+interest_time)*150- `omegabc2'))*0.9999 if interest_time <3
	replace lower_limit3 = ln((50-  `omegabc2')/((1+interest_time)*100- `omegabc2'))*0.9999 if interest_time==3
	replace lower_limit3 = ln((100- `omegabc2')/((1+interest_time)*50-  `omegabc2'))*0.9999 if interest_time==7
	replace lower_limit3 = ln((140- `omegabc2')/((1+interest_time)*10-  `omegabc2'))*0.9999 if interest_time==39

	gen upper_limit3 = ln((150- `omegabc2')/((1+interest_time)*0- `omegabc2'))


	
*****************************************************************	
*****************************************************************
*** FOR EXPONENTIAL UTILITY
*****************************************************************
*****************************************************************

** generate variables for estimation
	gen depvar4= time - ((1+interest_time)*(150-time))

** generate limits for tobit

	gen lower_limit4 =  0 - ((1+interest_time)*150) if interest_time <3
	replace lower_limit4 = 50 - ((1+interest_time)*100) if interest_time==3
	replace lower_limit4 = 100 - ((1+interest_time)*150) if interest_time==7
	replace lower_limit4 = 140 - ((1+interest_time)*10) if interest_time==39

	gen upper_limit4 = 150
	
	replace lower_limit4=-1500 if ra==1  //Avoids error of observations with ll() > ul() not allowed when running m24ts
//
	



***********************************************************************************************


***************************Appendix, Table 11

************Column 2
eststo m6t: tobit depvar ln_1_r no_check days  if interest<3 & inst==0  & map_id==., ll(lower_limit) ul(upper_limit) nocons vce(cluster identifier)
nlcom (alpha_m6t: (1/_b[ln_1_r]) +1) (delta_m6t: exp(_b[days]/_b[ln_1_r])) ///
(annual_discount_m6t: (1/(exp(_b[days]/_b[ln_1_r])))^365-1) ///
(P_no_check_m6t:exp(_b[no_check]/_b[ln_1_r])), post

************Column 1
eststo m7t: tobit depvar days ln_1_r no_check if interest<3 & inst==1 & map_id==., ll(lower_limit) ul(upper_limit) nocons vce(cluster identifier)
nlcom (alpha_m7t: (1/_b[ln_1_r]) +1) (delta_m7t: exp(_b[days]/_b[ln_1_r])) ///
(annual_discount_m7t: (1/(exp(_b[days]/_b[ln_1_r])))^365-1) ///
(P_no_check_m7t:exp(_b[no_check]/_b[ln_1_r])), post
test _b[P_no_check_m7t]=  .3238253
/* test _b[P_no_check_m7t]=  .3238253

 ( 1)  P_no_check_m7t = .3238253

           chi2(  1) =    2.61
         Prob > chi2 =    0.1063 */

		 
************Column 4
eststo m18t: tobit depvar3 ln_1_r no_check days  if interest<3 & inst==0 & map_id==., ll(lower_limit3) ul(upper_limit3) nocons vce(cluster identifier)
nlcom (alpha_m18t: (1/_b[ln_1_r]) +1) (delta_m18t: exp(_b[days]/_b[ln_1_r])) ///
(annual_discount_m18t: (1/(exp(_b[days]/_b[ln_1_r])))^365-1) ///
(P_no_check_m18t:exp(_b[no_check]/_b[ln_1_r])), post

************Column 3
eststo m19t: tobit depvar3 days ln_1_r no_check if interest<3 & inst==1 & map_id==. , ll(lower_limit3) ul(upper_limit3) nocons vce(cluster identifier)
nlcom (alpha_m19t: (1/_b[ln_1_r]) +1) (delta_m19t: exp(_b[days]/_b[ln_1_r])) ///
(annual_discount_m19t: (1/(exp(_b[days]/_b[ln_1_r])))^365-1) ///
(P_no_check_m19t:exp(_b[no_check]/_b[ln_1_r])), post
test _b[P_no_check_m19t]= .4418573 
/* test _b[P_no_check_m19t]= .4418573 

 ( 1)  P_no_check_m19t = .4418573

           chi2(  1) =    2.56
         Prob > chi2 =    0.1098 */

************Column 6
eststo m24t: tobit depvar4 ln_1_r no_check days  if interest<3 & inst==0 & map_id==., ll(lower_limit4) ul(upper_limit4) nocons vce(cluster identifier)
nlcom (rho_m24t:(-1/_b[ln_1_r])) (delta_m24t:exp(_b[days]/_b[ln_1_r])) ///
(annual_discount_m24t:(1/(exp(_b[days]/_b[ln_1_r]))^365-1)) ///
(P_no_check_m24t:exp(_b[no_check]/_b[ln_1_r])), post

************Column 5
eststo m25t: tobit depvar4 ln_1_r no_check  days  if interest<3 & inst==1 &map_id==., ll(lower_limit4) ul(upper_limit4) nocons vce(cluster identifier)
nlcom (rho_m25t:(-1/_b[ln_1_r])) (delta_m25t:exp(_b[days]/_b[ln_1_r])) ///
(annual_discount_m25t:(1/(exp(_b[days]/_b[ln_1_r]))^365-1)) ///
(P_no_check_m25t:exp(_b[no_check]/_b[ln_1_r])), post
test _b[P_no_check_m25t]=.5242353
/*test _b[P_no_check_m25t]=.5242353

 ( 1)  P_no_check_m25t = .5242353

           chi2(  1) =    2.64
         Prob > chi2 =    0.1042 */
*****************************************************************END OF TABLE 11


******************************************************************Appendix, Table 12************************************************************************************************************

*Column 1, NWTF
global omega=-0.01

ml model lf ML_crra_joint_mpl (alpha: mpl_risk mpl_time days interest_time interest_risk check ra prob const_a = ) (delta: ) (P: ) if treatment_inst=="Project Dungganon" & map_id==., cluster(identifier) missing  maximize technique(dfp) difficult trace showtolerance   init(0.30 0.98 0.50, copy)
ml display
estimates store mplnwtf
di [P]_cons
test [P]_cons= .43687646  

*Column 2, ML
ml model lf ML_crra_joint_mpl (alpha: mpl_risk mpl_time days interest_time interest_risk check ra prob const_a = ) (delta: ) (P: ) if treatment_inst!="Project Dungganon" & map_id==., cluster(identifier) missing  maximize technique(dfp) difficult trace showtolerance   init(0.30 0.98 0.50, copy)
estimates store mplnwtf
di [P]_cons  
ml display

global omega=-50.25



*Column 3, NWTF

ml model lf ML_crra_joint_mpl (alpha: mpl_risk mpl_time days interest_time interest_risk check ra prob const_a = ) (delta: ) (P: ) if treatment_inst=="Project Dungganon" & map_id==. , cluster(identifier) missing  maximize technique(dfp) difficult trace showtolerance   init(0.30 0.98 0.50, copy)
ml display
di [P]_cons
test [P]_cons=.10264975

*Column 4, ML

ml model lf ML_crra_joint_mpl (alpha: mpl_risk mpl_time days interest_time interest_risk check ra prob const_a = ) (delta: ) (P: ) if treatment_inst!="Project Dungganon" & map_id==. , cluster(identifier) missing  maximize technique(dfp) difficult trace showtolerance   init(0.30 0.98 0.50, copy)
di [P]_cons
ml display



 
** CARA


*Column 5, NWTF

global omega=0
ml model lf ML_cara_joint_mpl (rho: mpl_risk mpl_time days interest_time interest_risk check ra prob const_a = ) (delta: ) (P: ) if treatment_inst=="Project Dungganon" & map_id==. , cluster(identifier) missing  maximize technique(dfp) difficult trace showtolerance   init(0.005 0.98 0.50, copy)
ml display
di [P]_cons 
test [P]_cons=.5167679



*Column 6, ML
ml model lf ML_cara_joint_mpl (rho: mpl_risk mpl_time days interest_time interest_risk check ra prob const_a = ) (delta: ) (P: ) if treatment_inst!="Project Dungganon" & map_id==. , cluster(identifier) missing  maximize technique(dfp) difficult trace showtolerance   init(0.005 0.98 0.50, copy)
ml display
di [P]_cons 



**************************************************************************************************************************************************************************************************
************Table 13:CRRA and CARA parameters estimates, specification 3.*******************************************************************
global omega=-0.01
*Column 1, NWTF
ml model lf ML_ra_crra (alpha: risk time days interest_time interest_risk check ra prob = ) (delta: ) (P: ) if treatment_inst=="Project Dungganon" & map_id==., cluster(identifier) missing  maximize technique(dfp) difficult trace showtolerance   init(1.85 0.94 0.30, copy)
ml display




*Column 2, ML

ml model lf ML_ra_crra (alpha: risk time days interest_time interest_risk check ra prob = ) (delta: ) (P: ) if treatment_inst=="Money Lender", cluster(identifier) missing  maximize technique(dfp) difficult trace showtolerance   init(1.85 0.94 0.30, copy)
ml display




global omega=-50.25
*Column 3, NWTF
ml model lf ML_ra_crra (alpha: risk time days interest_time interest_risk check ra prob = ) (delta: ) (P: ) if treatment_inst=="Project Dungganon" & map_id==., cluster(identifier) missing  maximize technique(dfp) difficult trace showtolerance   init(1.85 0.94 0.30, copy)
ml display




*Column 4, ML

ml model lf ML_ra_crra (alpha: risk time days interest_time interest_risk check ra prob = ) (delta: ) (P: ) if treatment_inst=="Money Lender", cluster(identifier) missing  maximize technique(dfp) difficult trace showtolerance   init(1.85 0.94 0.30, copy)
ml display

*****NOTE: Complete results of column 4 available at the end of the document**************

global omega=-0.01
*Column 5, NWTF

ml model lf ML_ra_cara (rho: risk time days interest_time interest_risk check ra prob = ) (delta: ) (P: ) if treatment_inst=="Project Dungganon" & map_id==., cluster(identifier) missing  maximize technique(dfp) difficult trace showtolerance   init(0.005 0.94 0.30, copy)
ml display

/*RESULTS Column 5: RAN: 17.07.2023

                                                        Number of obs = 30,240
                                                        Wald chi2(0)  =      .
Log pseudolikelihood = -138312.77                       Prob > chi2   =      .

                           (Std. err. adjusted for 560 clusters in identifier)
------------------------------------------------------------------------------
             |               Robust
             | Coefficient  std. err.      z    P>|z|     [95% conf. interval]
-------------+----------------------------------------------------------------
rho          |
       _cons |  -.0062092   .0003901   -15.92   0.000    -.0069738   -.0054446
-------------+----------------------------------------------------------------
delta        |
       _cons |   .9876939   .0027813   355.11   0.000     .9822425    .9931452
-------------+----------------------------------------------------------------
P            |
       _cons |   .2844995   .0223914    12.71   0.000     .2406132    .3283858
------------------------------------------------------------------------------



*/


*Column 6, ML
ml model lf ML_ra_cara (rho: risk time days interest_time interest_risk check ra prob = ) (delta: ) (P: ) if treatment_inst=="Money Lender" & map_id==., cluster(identifier) missing  maximize technique(dfp) difficult trace showtolerance   init(0.005 0.94 0.30, copy)
ml display




/* /*RESULTS Column 6: RAN: 17.07.2023
                                                        Number of obs = 28,782
                                                        Wald chi2(0)  =      .
Log pseudolikelihood = -131864.11                       Prob > chi2   =      .

                           (Std. err. adjusted for 533 clusters in identifier)
------------------------------------------------------------------------------
             |               Robust
             | Coefficient  std. err.      z    P>|z|     [95% conf. interval]
-------------+----------------------------------------------------------------
rho          |
       _cons |  -.0060065   .0003972   -15.12   0.000     -.006785    -.005228
-------------+----------------------------------------------------------------
delta        |
       _cons |   .9797137   .0027492   356.36   0.000     .9743254     .985102
-------------+----------------------------------------------------------------
P            |
       _cons |   .2819539   .0233134    12.09   0.000     .2362605    .3276474
------------------------------------------------------------------------------
*/



/* Results Table 13, column 4: 

ml model lf ML_ra_crra (alpha: risk time days interest_time interest_risk check ra prob = ) (delta: ) (P: ) if treatment_inst=="Money Lender", cluster(identifier) mi
> ssing  maximize technique(dfp) difficult trace showtolerance   init(1.85 0.94 0.30, copy)

initial:       log pseudolikelihood = -132453.26
rescaling entire vector ..
rescale:       log pseudolikelihood = -132453.26
rescaling equations .....+.
rescaling equations ......
rescale eq:    log pseudolikelihood = -132377.17
-----------------------------------------------------------------------------------------------------------------------------------------------------------------------
Iteration 0:
Parameter vector:
     alpha:  delta:      P:
     _cons   _cons   _cons
r1    1.85     .94      .6

                                             log pseudolikelihood = -132377.17
-----------------------------------------------------------------------------------------------------------------------------------------------------------------------
Iteration 1:
Parameter vector:
       alpha:    delta:        P:
       _cons     _cons     _cons
r1  1.851607   .979492  .5996235

                                             log pseudolikelihood = -132130.11
                                                                   (backed up)
                                                             vtol =  .00186625
-----------------------------------------------------------------------------------------------------------------------------------------------------------------------
Iteration 2:
Parameter vector:
       alpha:    delta:        P:
       _cons     _cons     _cons
r1  2.129205  .9903875  .1646987

                                             log pseudolikelihood = -131786.17
                                                                   (backed up)
                                                             vtol =  .00260304
-----------------------------------------------------------------------------------------------------------------------------------------------------------------------
Iteration 3:
Parameter vector:
       alpha:    delta:        P:
       _cons     _cons     _cons
r1  2.599255  .9826844  .2084516

                                             log pseudolikelihood = -131752.46
                                                                   (backed up)
                                                             vtol =  .00025582
-----------------------------------------------------------------------------------------------------------------------------------------------------------------------
Iteration 4:
Parameter vector:
       alpha:    delta:        P:
       _cons     _cons     _cons
r1  2.192885  .9726275  .3450194

                                             log pseudolikelihood =  -131711.6
                                                             vtol =  .00031013
-----------------------------------------------------------------------------------------------------------------------------------------------------------------------
Iteration 5:
Parameter vector:
       alpha:    delta:        P:
       _cons     _cons     _cons
r1  2.400604  .9729831  .2633248

                                             log pseudolikelihood = -131662.69
                                                             vtol =  .00037135
-----------------------------------------------------------------------------------------------------------------------------------------------------------------------
Iteration 6:
Parameter vector:
       alpha:    delta:        P:
       _cons     _cons     _cons
r1  2.376416   .974221  .2580883

                                             log pseudolikelihood = -131661.91
                                                             vtol =  5.918e-06
-----------------------------------------------------------------------------------------------------------------------------------------------------------------------
Iteration 7:
Parameter vector:
       alpha:    delta:        P:
       _cons     _cons     _cons
r1  2.373935   .974113  .2584194

                                             log pseudolikelihood = -131661.89
                                                             qtol =  .00013789
-----------------------------------------------------------------------------------------------------------------------------------------------------------------------
Iteration 8:
Parameter vector:
       alpha:    delta:        P:
       _cons     _cons     _cons
r1  2.374127  .9741189  .2583117

                                             log pseudolikelihood = -131661.89
                                                      g inv(H) g' =  7.161e-06
-----------------------------------------------------------------------------------------------------------------------------------------------------------------------

. ml display

                                                        Number of obs = 28,782
                                                        Wald chi2(0)  =      .
Log pseudolikelihood = -131661.89                       Prob > chi2   =      .

                           (Std. err. adjusted for 533 clusters in identifier)
------------------------------------------------------------------------------
             |               Robust
             | Coefficient  std. err.      z    P>|z|     [95% conf. interval]
-------------+----------------------------------------------------------------
alpha        |
       _cons |   2.374127   .0748718    31.71   0.000     2.227381    2.520873
-------------+----------------------------------------------------------------
delta        |
       _cons |   .9741189   .0029662   328.41   0.000     .9683053    .9799325
-------------+----------------------------------------------------------------
P            |
       _cons |   .2583117     .02353    10.98   0.000     .2121937    .3044296
------------------------------------------------------------------------------

*/