

****************JOINT ESTIMATION RISK ATTITUDES & TIME PREFERENCES*********************************

pause on

program ML_crra_joint_mpl

args lnf alpha delta P


* `int': interest rate r
* `prob': winning probability in lottery
* `nuT': nu for quantal response time
* `mult': multiplier r in time
* `trust': Trust indicator P
* `delta': Discount factor delta	
*d: Later payment delay in days

tempvar yLW yLL euS euL euI_L euI_S euI wp ra risk int a 

tempvar yN yL yL_NP yw du_N du_L duI_N duI_L duI time d mult check 



quietly {

generate double `risk'= $ML_y1
generate double `time'= $ML_y2
generate double `d'= $ML_y3
generate double `mult'= $ML_y4
generate double `int'= $ML_y5
generate double `check'= $ML_y6
generate double `ra'= $ML_y7
generate double `wp'= $ML_y8
generate double `a'= $ML_y9



********** RISK***************


*transform paramaters


generate double `yLW' = ((((1+`int')*(150-`a'))+`a'-$omega )^(`alpha'))/(`alpha')   if `ra'==1
generate double `yLL' = ((0+`a'-$omega )^(`alpha'))/(`alpha')   if `ra'==1
generate double `euS'= ((150-$omega )^(`alpha'))/(`alpha')   if `ra'==1

replace `yLW' = ln(((1+`int')*(150-`a'))+`a'-$omega)    if `ra'==1 & `alpha'==0
replace `yLL' = ln(0+`a'-$omega)    if `ra'==1 & `alpha'==0
replace `euS' = ln(150 - $omega) if `ra'==1 & `alpha'==0

generate double `euL' = `wp'*`yLW' + (1-`wp')*`yLL'  if `ra'==1

* save predicted risk results

replace Pchoice=0 if `euS'<`euL' & `ra'==1
replace Pchoice=1 if `euS'>`euL' & `ra'==1



generate double `euI_L'=(`euL'^(1/1))
generate double `euI_S'=(`euS'^(1/1))

generate double `euI'=`euI_L'/(`euI_L' +`euI_S') if `ra'==1



replace `lnf'=ln(`euI') if `risk'!=150 & `ra'==1
replace `lnf'=ln(1-`euI') if `risk'==150 & `ra'==1



************ TIME ***************



generate double `yN' = 0
generate double `yL' = 0
generate double `yL_NP' = 0
generate double `yw' = 0

replace `yN' = ((150-$omega)^(`alpha'))/(`alpha')   if `ra'==0
replace `yL' = ((((1+`mult')*(150-`a'))-$omega)^(`alpha'))/(`alpha')   if `ra'==0
replace `yL_NP' = ((0-$omega)^(`alpha'))/(`alpha')   if `ra'==0
replace `yw' = ((`a'-$omega)^(`alpha'))/(`alpha')   if `ra'==0

generate double `du_N'=0
generate double `du_L'=0

replace `du_N' = `yN' + (`delta')^`d'*`yL_NP'
replace `du_L' = `yw' + `P'*(`delta')^`d'*`yL' +  (1-`P')*(`delta')^`d'*`yL_NP' if `ra' == 0 & `check'==0 //check=0, no check as securement, P<1 
replace `du_L' = `yw' + (`delta')^`d'*`yL' if `ra' == 0 & `check'==1 									//check=0, no check as securement, P<1 

* save predicted time results
replace PTchoice=0 if `du_N' > `du_L' & `ra'==0
replace PTchoice=1 if `du_N' < `du_L' & `ra'==0

generate double `duI_N' = `du_N'^(1/1) if `ra'==0
generate double `duI_L' = `du_L'^(1/1) if `ra'==0

generate double `duI' = (`duI_N')/(`duI_N'+`duI_L') if `ra'==0

replace `lnf' = ln(`duI') if `time'==150 & `ra'==0
replace `lnf' = ln(1-`duI') if `time'!=150 & `ra'==0

replace timeln=`lnf'
}
end


***********MPL******************
****************JOINT ESTIMATION RISK ATTITUDES & TIME PREFERENCES (CARA)*********************************

pause on

program ML_cara_joint_mpl

args lnf rho delta P


* `int': interest rate r
* `prob': winning probability in lottery
* `nuT': nu for quantal response time
* `mult': multiplier r in time
* `trust': Trust indicator P
* `delta': Discount factor delta	
*d: Later payment delay in days

tempvar yLW yLL euS euL euI_L euI_S euI wp ra risk int a 
*max

tempvar yN yL yL_NP yw du_N du_L duI_N duI_L duI time d mult check 



quietly {

generate double `risk'= $ML_y1
generate double `time'= $ML_y2
generate double `d'= $ML_y3
generate double `mult'= $ML_y4
generate double `int'= $ML_y5
generate double `check'= $ML_y6
generate double `ra'= $ML_y7
generate double `wp'= $ML_y8
generate double `a'= $ML_y9



********** RISK***************


*transform paramaters


generate double `yLW' = (1-exp(-`rho'*(((1+`int')*(150-`a'))+`a'-$omega )))/`rho'   if `ra'==1
generate double `yLL' = (1-exp(-`rho'*(0+`a'-$omega )))/`rho'   if `ra'==1
generate double `euS'=  (1-exp(-`rho'*(150-$omega )))/`rho'   if `ra'==1

generate double `euL' = `wp'*`yLW' + (1-`wp')*`yLL'  if `ra'==1

* save predicted risk results

replace Pchoice=0 if `euS'<`euL' & `ra'==1
replace Pchoice=1 if `euS'>`euL' & `ra'==1


generate double `euI_L'=(`euL'^(1/1))
generate double `euI_S'=(`euS'^(1/1))

generate double `euI'=`euI_L'/(`euI_L' +`euI_S') if `ra'==1



replace `lnf'=ln(`euI') if `risk'!=150 & `ra'==1
replace `lnf'=ln(1-`euI') if `risk'==150 & `ra'==1



************ TIME ***************



generate double `yN' = 0
generate double `yL' = 0
generate double `yL_NP' = 0
generate double `yw' = 0

replace `yN' = (1-exp(-`rho'*((150-$omega ))))/`rho'   if `ra'==0
replace `yL' = (1-exp(-`rho'*(((1+`mult')*(150-`a'))-$omega )))/`rho'   if `ra'==0
replace `yL_NP' = (1-exp(-`rho'*(0-$omega )))/`rho'   if `ra'==0
replace `yw' = (1-exp(-`rho'*(`a'-$omega )))/`rho'   if `ra'==0

generate double `du_N'=0
generate double `du_L'=0

replace `du_N' = `yN' + (`delta')^`d'*`yL_NP'
replace `du_L' = `yw' + `P'*(`delta')^`d'*`yL' +  (1-`P')*(`delta')^`d'*`yL_NP' if `ra' == 0 & `check'==0 //check=0, no check as securement, P<1 
replace `du_L' = `yw' + (`delta')^`d'*`yL' if `ra' == 0 & `check'==1 									//check=0, no check as securement, P<1 

* save predicted time results
replace PTchoice=0 if `du_N' > `du_L' & `ra'==0
replace PTchoice=1 if `du_N' < `du_L' & `ra'==0

generate double `duI_N' = `du_N'^(1/1) if `ra'==0
generate double `duI_L' = `du_L'^(1/1) if `ra'==0

generate double `duI' = (`duI_N')/(`duI_N'+`duI_L') if `ra'==0

replace `lnf' = ln(`duI') if `time'==150 & `ra'==0
replace `lnf' = ln(1-`duI') if `time'!=150 & `ra'==0

replace timeln=`lnf'
}
end



*********************************************************Joint Estimation using Convex Data*********************************************************

program ML_ra_crra

*args lnf alpha delta P muRA nuT
args lnf alpha delta P

* estimating over risk responses

* `int': interest rate r
* `prob': winning probability in lottery
* `muRA': mu for quantal response risk
* `nuT': nu for quantal response time
* `mult': multiplier r in time
* `trust': Trust indicator P
* `delta': Discount factor delta	
*d: Later payment delay in days

forvalues k=0(1)150 {
tempvar yLW_`k' yLL_`k' eu_`k' euD_`k' euI_`k' yN_`k' yL_`k' du_`k' duD_`k' duI_`k'
}
tempvar  wp ra max maxT denom d denomT risk time mult int check yL_NP


quietly {
generate double `risk'= $ML_y1
generate double `time'= $ML_y2
generate double `d'= $ML_y3
generate double `mult'= $ML_y4
generate double `int'= $ML_y5
generate double `check'= $ML_y6
generate double `ra'= $ML_y7
generate double `wp'= $ML_y8

forvalues C = 0(1)150 {
generate double `yLW_`C'' = ((((1+`int')*(150-`C'))+`C'-$omega)^(`alpha'))/(`alpha')   if `ra'==1
generate double `yLL_`C'' = ((0+`C'-$omega)^(`alpha'))/(`alpha')   if `ra'==1
}



forvalues C = 0(1)150 {
generate double `eu_`C'' = `wp'*`yLW_`C'' + (1-`wp')*`yLL_`C''  if `ra'==1
}

* save predicted risk results

generate double `max' = -1 

forvalues j = 0(1)150 {
replace Pchoice = `j' if `eu_`j'' > `max' & `eu_`j'' < . & `ra'==1 & `int'<3
replace `max' = `eu_`j'' if `eu_`j'' > `max' & `eu_`j'' < . & `ra'==1 & `int'<3
}


forvalues j = 50(1)150 {
replace Pchoice = `j' if `eu_`j'' > `max' & `eu_`j'' < . & `ra'==1 & `int'==3
replace `max' = `eu_`j'' if `eu_`j'' > `max' & `eu_`j'' < . & `ra'==1 & `int'==3
}


forvalues j = 0(1)150 {
generate double `euD_`j''=`eu_`j''/`max' if `ra'==1  //normalizes the expected utility, so that euI does not explode
}


forvalues C = 0(1)150 {
generate double `euI_`C'' = (`euD_`C'')^(1/1) if `ra'==1
}


generate double `denom'=0
forvalues x=0(1)150 {
replace `denom'=`denom'+`euI_`x'' if `ra'==1 & `int'<3
}

forvalues x=50(1)150 {
replace `denom'=`denom'+`euI_`x'' if `ra'==1 & `int'==3
}


forvalues x=0(1)150 {
replace `lnf'=ln(`euI_`x''/`denom') if `ra'==1 & `risk'==`x'
}

* estimating over time responses

forvalues L = 0(1)150 {
generate double `yN_`L'' = ((`L'-$omega)^(`alpha'))/(`alpha')   if `ra'==0
generate double `yL_`L'' = ((((1+`mult')*(150-`L'))-$omega)^(`alpha'))/(`alpha')   if `ra'==0
}
generate double `yL_NP' = ((0-$omega)^(`alpha'))/(`alpha')   if `ra'==0

forvalues L = 0(1)150 {
generate double `du_`L'' = 0
replace `du_`L'' = `yN_`L'' + `P'*(`delta')^`d'*`yL_`L'' +  (1-`P')*(`delta')^`d'*`yL_NP' if `ra' == 0 & `check'==0 //check=0, no check as securement, P<1 
replace `du_`L'' = `yN_`L'' + (`delta')^`d'*`yL_`L''  if `ra' == 0 & `check'==1 //check=0, no check as securement, P=1 
}

* save predicted time results

generate double `maxT' = -1 

forvalues j = 0(1)150 {
replace PTchoice = `j' if `du_`j'' > `maxT' & `du_`j'' < . & `ra'==0 & `mult'<3
replace `maxT' = `du_`j'' if `du_`j'' > `maxT' & `du_`j'' < . & `ra'==0 & `mult'<3
}

forvalues j = 50(1)150 {
replace PTchoice = `j' if `du_`j'' > `maxT' & `du_`j'' < . & `ra'==0 & `mult'==3
replace `maxT' = `du_`j'' if `du_`j'' > `maxT' & `du_`j'' < . & `ra'==0 & `mult'==3
}

forvalues j = 100(1)150 {
replace PTchoice = `j' if `du_`j'' > `maxT' & `du_`j'' < . & `ra'==0 & `mult'==7
replace `maxT' = `du_`j'' if `du_`j'' > `maxT' & `du_`j'' < . & `ra'==0 & `mult'==7
}

forvalues j = 140(1)150 {
replace PTchoice = `j' if `du_`j'' > `maxT' & `du_`j'' < . & `ra'==0 & `mult'==39
replace `maxT' = `du_`j'' if `du_`j'' > `maxT' & `du_`j'' < . & `ra'==0 & `mult'==39
}

forvalues j = 0(1)150 {
generate double `duD_`j''=`du_`j''/`maxT' if `ra'==0 //normalizes the discounted utility, so that euI does not explode
}

forvalues C = 0(1)150 {
generate double `duI_`C'' = (`duD_`C'')^(1/1) if `ra'==0
}


generate double `denomT'=0
forvalues x=0(1)150 {
replace `denomT'=`denomT'+`duI_`x'' if `ra'==0 & `mult'<3
}
forvalues x=50(1)150 {
replace `denomT'=`denomT'+`duI_`x'' if `ra'==0 & `mult'==3
}
forvalues x=100(1)150 {
replace `denomT'=`denomT'+`duI_`x'' if `ra'==0 & `mult'==7
}
forvalues x=140(1)150 {
replace `denomT'=`denomT'+`duI_`x'' if `ra'==0 & `mult'==39
}



forvalues x=0(1)150 {
replace `lnf'=ln(`duI_`x''/`denomT') if `ra'==0 & `time'==`x'
}

sum `lnf' `alpha' `delta' `P' `muRA' `nuT'

replace `lnf'=-50 if `lnf'==.
sum `lnf' `alpha' `delta' `P' `muRA' `nuT'
replace timeln=`lnf'
}

end

************************************************************************************

program ML_ra_cara

*args lnf rho delta P muRA nuT
args lnf rho delta P

* estimating over risk responses

* `int': interest rate r
* `prob': winning probability in lottery
* `muRA': mu for quantal response risk
* `nuT': nu for quantal response time
* `mult': multiplier r in time
* `trust': Trust indicator P
* `delta': Discount factor delta	
*d: Later payment delay in days

forvalues k=0(1)150 {
tempvar yLW_`k' yLL_`k' eu_`k' euD_`k' euI_`k' yN_`k' yL_`k' du_`k' duD_`k' duI_`k'
}
tempvar  wp ra max maxT denom d denomT risk time mult int check yL_NP

quietly {
generate double `risk'= $ML_y1
generate double `time'= $ML_y2
generate double `d'= $ML_y3
generate double `mult'= $ML_y4
generate double `int'= $ML_y5
generate double `check'= $ML_y6
generate double `ra'= $ML_y7
generate double `wp'= $ML_y8

forvalues C = 0(1)150 {
generate double `yLW_`C'' = (1-exp(-`rho'*(((1+`int')*(150-`C'))+`C'-$omega )))/`rho'   if `ra'==1
generate double `yLL_`C'' = (1-exp(-`rho'*(0+`C'-$omega )))/`rho'   if `ra'==1
}


forvalues C = 0(1)150 {
generate double `eu_`C'' = `wp'*`yLW_`C'' + (1-`wp')*`yLL_`C''  if `ra'==1
}


* save predicted risk results

generate double `max' = -1 

forvalues j = 0(1)150 {
replace Pchoice = `j' if `eu_`j'' > `max' & `eu_`j'' < . & `ra'==1 & `int'<3
replace `max' = `eu_`j'' if `eu_`j'' > `max' & `eu_`j'' < . & `ra'==1 & `int'<3
}


forvalues j = 50(1)150 {
replace Pchoice = `j' if `eu_`j'' > `max' & `eu_`j'' < . & `ra'==1 & `int'==3
replace `max' = `eu_`j'' if `eu_`j'' > `max' & `eu_`j'' < . & `ra'==1 & `int'==3
}

forvalues j = 0(1)150 {
generate double `euD_`j''=`eu_`j''/`max' if `ra'==1  //normalizes the expected utility, so that euI does not explode
}


forvalues C = 0(1)150 {
generate double `euI_`C'' = (`euD_`C'')^(1/1) if `ra'==1
}

generate double `denom'=0
forvalues x=0(1)150 {
replace `denom'=`denom'+`euI_`x'' if `ra'==1 & `int'<3
}

forvalues x=50(1)150 {
replace `denom'=`denom'+`euI_`x'' if `ra'==1 & `int'==3
}


forvalues x=0(1)150 {
replace `lnf'=ln(`euI_`x''/`denom') if `ra'==1 & `risk'==`x'
}

forvalues L = 0(1)150 {
generate double `yN_`L'' = (1-exp(-`rho'*(`L'-$omega )))/`rho'   if `ra'==0
generate double `yL_`L'' = (1-exp(-`rho'*(((1+`mult')*(150-`L'))-$omega )))/`rho'   if `ra'==0
}
generate double `yL_NP' = (1-exp(-`rho'*(0-$omega )))/`rho'   if `ra'==0


forvalues L = 0(1)150 {
generate double `du_`L'' = 0
replace `du_`L'' = `yN_`L'' + `P'*(`delta')^`d'*`yL_`L'' +  (1-`P')*(`delta')^`d'*`yL_NP' if `ra' == 0 & `check'==0 //check=0, no check as securement, P<1 
replace `du_`L'' = `yN_`L'' + (`delta')^`d'*`yL_`L''  if `ra' == 0 & `check'==1 //check=0, no check as securement, P=1 
}

* save predicted time results

generate double `maxT' = -1 

forvalues j = 0(1)150 {
replace PTchoice = `j' if `du_`j'' > `maxT' & `du_`j'' < . & `ra'==0 & `mult'<3
replace `maxT' = `du_`j'' if `du_`j'' > `maxT' & `du_`j'' < . & `ra'==0 & `mult'<3
}

forvalues j = 50(1)150 {
replace PTchoice = `j' if `du_`j'' > `maxT' & `du_`j'' < . & `ra'==0 & `mult'==3
replace `maxT' = `du_`j'' if `du_`j'' > `maxT' & `du_`j'' < . & `ra'==0 & `mult'==3
}

forvalues j = 100(1)150 {
replace PTchoice = `j' if `du_`j'' > `maxT' & `du_`j'' < . & `ra'==0 & `mult'==7
replace `maxT' = `du_`j'' if `du_`j'' > `maxT' & `du_`j'' < . & `ra'==0 & `mult'==7
}

forvalues j = 140(1)150 {
replace PTchoice = `j' if `du_`j'' > `maxT' & `du_`j'' < . & `ra'==0 & `mult'==39
replace `maxT' = `du_`j'' if `du_`j'' > `maxT' & `du_`j'' < . & `ra'==0 & `mult'==39
}

forvalues j = 0(1)150 {
generate double `duD_`j''=`du_`j''/`maxT' if `ra'==0 //normalizes the discounted utility, so that euI does not explode
}

forvalues C = 0(1)150 {
generate double `duI_`C'' = (`duD_`C'')^(1/1) if `ra'==0
}

generate double `denomT'=0
forvalues x=0(1)150 {
replace `denomT'=`denomT'+`duI_`x'' if `ra'==0 & `mult'<3
}
forvalues x=50(1)150 {
replace `denomT'=`denomT'+`duI_`x'' if `ra'==0 & `mult'==3
}
forvalues x=100(1)150 {
replace `denomT'=`denomT'+`duI_`x'' if `ra'==0 & `mult'==7
}
forvalues x=140(1)150 {
replace `denomT'=`denomT'+`duI_`x'' if `ra'==0 & `mult'==39
}



forvalues x=0(1)150 {
replace `lnf'=ln(`duI_`x''/`denomT') if `ra'==0 & `time'==`x'
}

sum `lnf' `rho' `delta' `P' `muRA' `nuT'

replace `lnf'=-50 if `lnf'==.
sum `lnf' `rho' `delta' `P' `muRA' `nuT'

replace timeln=`lnf'
}

end

