// created by Maria Isabel Santana
//created on: 05.07.2023

*****************FIGURES: 4 and Appendix figures 8, 9, 10**********************************

*****************TABLES: 4, 5, 6, 9, and Appendix tables 14, 15, 16*****************





global omega=-0.01

use "$WORKING_ANALYSIS\games_time_and_risk_longS.dta", clear


gen Pchoice=.
gen PTchoice=.
gen timeln=.

*****************Figure 4********************************************************************

preserve
	keep if map_id==. & ra==0
	collapse (mean) time, by(interest1 days check)
	twoway (scatter time interest1 if interest1<4 & days==7, msymbol(+)) ///
	(scatter time interest1 if interest1<4 & days==28) ///
	, by(check, note("") graphregion(color(white)) bgcolor(white)) ytitle(Current allocation) xtitle(Interest rate 1 + r) ///
	legend(order(1 "d=7" 2 "d=28")) subtitle(,  fcolor(gs14) lcolor(gs14))
	graph export "$WORKING_ANALYSIS\Figure4b.pdf", replace
	restore
	
	preserve
	keep if map_id==. & ra==0
	collapse (mean) time, by(interest1 treatment_inst check)
	twoway (scatter time interest1 if interest1<4 & treatment_inst=="Money Lender", msymbol(+)) ///
	(scatter time interest1 if interest1<4 & treatment_inst=="Project Dungganon") ///
	, by(check, note("") graphregion(color(white)) bgcolor(white)) ytitle(Current allocation) xtitle(Interest rate 1 + r) ///
	legend(order(1 "ML" 2 "NWTF")) subtitle(,  fcolor(gs14) lcolor(gs14))
	graph export "$WORKING_ANALYSIS\Figure4a.pdf", replace
	restore

*************************

*******************************Figure 8, Appendix*********************************************************************************************
label var time "Ct"

histogram time if interest<3, width(1) start(0)  ///
 fraction fcolor(black) lcolor(gs8) graphregion(color(white)) bgcolor(white)
graph export "$WORKING_ANALYSIS\Figure8.pdf",  replace




*****Figure 9, appendix

preserve
	keep if ra==0 &  map_id==. 
	collapse (mean) time, by(interest1 treatment_inst check)
	twoway (scatter time interest1 if interest1>3 & treatment_inst=="Money Lender", msymbol(+) ylabel(80(20)150 150))  ///
	(scatter time interest1 if  interest1>3 & treatment_inst=="Project Dungganon") ///
	, by(check, note("") graphregion(color(white)) bgcolor(white)) ytitle(Current allocation) xtitle(Interest rate 1 + r) ///
	legend(order(1 "ML" 2 "NWTF")) subtitle(,  fcolor(gs14) lcolor(gs14))  ylabel(80(20)150 150)
	graph export "$WORKING_ANALYSIS\Figure9a.pdf", replace
	restore
	
	
	preserve
	keep if ra==0 & map_id==. 
	collapse (mean) time, by(interest1 days check)
	twoway (scatter time interest1 if interest1>3 & days==7, msymbol(+) ylabel(80(20)150 150)) ///
	(scatter time interest1 if interest1>3 & days==28) ///
	, by(check, note("") graphregion(color(white)) bgcolor(white)) ytitle(Current allocation) xtitle(Interest rate 1 + r) ///
	legend(order(1 "d=7" 2 "d=28")) subtitle(,  fcolor(gs14) lcolor(gs14)) ylabel(80(20)150 150)
	graph export "$WORKING_ANALYSIS\Figure9b.pdf", replace
	restore
	
	
*****Figure 10, appendix

*Current Consumption by interest rate and institution: check, no check if check_first==0 (NC/C)
	preserve
	keep if check_first==0 & ra==0  & map_id==. 
	collapse (mean) time, by(interest1 treatment_inst check)
	twoway (scatter time interest1 if interest1<3 & treatment_inst=="Money Lender", msymbol(+)) ///
	(scatter time interest1 if interest1<3 & treatment_inst=="Project Dungganon") ///
	, by(check, note("") graphregion(color(white)) bgcolor(white)) ytitle(Current allocation) xtitle(interest rate 1 + r) ///
	legend(order(1 "ML" 2 "NWTF")) subtitle(,  fcolor(gs14) lcolor(gs14)) ysc(r(50 120))
	graph export "$WORKING_ANALYSIS\Figure10a.pdf", replace
	restore
	
	*Current Consumption by interest rate and institution: check, no check if check_first==1 (C/NC)
	preserve
	keep if check_first==1 & ra==0  & map_id==. 
	collapse (mean) time, by(interest1 treatment_inst check)
	twoway (scatter time interest1 if interest1<3 & treatment_inst=="Money Lender", msymbol(+)) ///
	(scatter time interest1 if interest1<3 & treatment_inst=="Project Dungganon") ///
	, by(check, note("") graphregion(color(white)) bgcolor(white)) ytitle(Current allocation) xtitle(interest rate 1 + r) ///
	legend(order(1 "ML" 2 "NWTF"))  subtitle(,  fcolor(gs14) lcolor(gs14)) ysc(r(50 120))
	graph export "$WORKING_ANALYSIS\Figure10b.pdf", replace
	restore		


********************Table 4
		
	
	***PAPER TABLE 4: ttest by No-Check/Check: For the entire sample, for the NWTF sample, and ML sample
	eststo clear
	sort check
	eststo: estpost ttest time if map_id==. & ra==0, by(check) //Check vs No Check
eststo: estpost ttest time if map_id==. & ra==0 & treatment_inst=="Project Dungganon", by(check) 
eststo: estpost ttest time if map_id==. & ra==0 & treatment_inst=="Money Lender", by(check) 
	esttab using "$WORKING_ANALYSIS\Table4_panel1.tex", replace se label title(Equality of Means Test: No-Check vs Check\label{tab1}) mtitles ("All" "NWTF" "ML") star (* 0.10 ** 0.05 *** 0.01)
*****************************

***PAPER TABLE 4: ttest by institutions for the entire sample, for those with a check, and those with no check
eststo clear
	sort treatment_inst
	eststo: estpost ttest time if map_id==. & ra==0, by(treatment_inst) //NWTF vs ML
	eststo: estpost ttest time if map_id==. & ra==0 & check==1, by(treatment_inst) 
	eststo: estpost ttest time if map_id==. & ra==0 & check==0, by(treatment_inst) 
	esttab using "$WORKING_ANALYSIS\Table4_panel2.tex", replace se label title(Equality of Means Test: NWTF vs ML\label{tab1}) mtitles ("All" "Check" "No Check") star (* 0.10 ** 0.05 *** 0.01)
*****************************

	
eststo clear
sort intid
	eststo: estpost ttest time if map_id==. & ra==0, by(intid) //interest=1 vs interest=2.67
	eststo: estpost ttest time if map_id==. & ra==0 & check==1, by(intid) 
	eststo: estpost ttest time if map_id==. & ra==0 & check==0, by(intid) 
	esttab using "$WORKING_ANALYSIS\Table4_panel3.tex", replace se label title(Equality of Means Test: Interest=1 vs Interest=2.67\label{tab1}) mtitles ("All" "Check" "No Check") star (* 0.10 ** 0.05 *** 0.01)
*****************************




************************************************************************************************************************************************************************************************************************************
************************************TABLE 5 ******************************************************************************************************************************************************************************************
************************************************************************************************************************************************************************************************************************************
************************************************************************************************************************************************************************************************************************************

xtset subid


** define outside consumption
	local omega = -0.01

** generate variables for estimation
	gen depvar = ln((time - `omega') / ((1+interest_time)*(150-time) - `omega'))

	gen ln_1_r = ln(1+interest_time)

** treatment dummies
	gen no_check = 1-check

** generate limits for tobit

	gen lower_limit =     ln((0-   `omega')/((1+interest_time)*150- `omega'))*0.9999 if interest_time <3
	replace lower_limit = ln((50-  `omega')/((1+interest_time)*100- `omega'))*0.9999 if interest_time==3
	replace lower_limit = ln((100- `omega')/((1+interest_time)*50-  `omega'))*0.9999 if interest_time==7
	replace lower_limit = ln((140- `omega')/((1+interest_time)*10-  `omega'))*0.9999 if interest_time==39

	gen upper_limit = ln((150- `omega')/((1+interest_time)*0- `omega'))






gen back_cons_mod=back_cons
replace back_cons_mod=back_cons_hh/hh_size if back_cons==0
sum back_cons_mod

gen back_cons_mod2=back_cons
replace back_cons_mod2=back_cons_hh/hh_size if back_cons<back_cons_hh

gen back_cons_mod_daily=back_cons_mod/7



******************************************************************
******************************************************************
** AVERAGE DAILY CONSUMPTION AS THE BACKGROUND CONSUMPTION
******************************************************************
******************************************************************

	

* define outside consumption
	sum back_cons_mod_daily
		local omegabc2 = -r(mean)
		di `omegabc2'

** generate variables for estimation
	gen depvar3 = ln((time - `omegabc2') / ((1+interest_time)*(150-time) - `omegabc2'))

** generate limits for tobit
	gen lower_limit3 =     ln((0-   `omegabc2')/((1+interest_time)*150- `omegabc2'))*0.9999 if interest_time <3
	replace lower_limit3 = ln((50-  `omegabc2')/((1+interest_time)*100- `omegabc2'))*0.9999 if interest_time==3
	replace lower_limit3 = ln((100- `omegabc2')/((1+interest_time)*50-  `omegabc2'))*0.9999 if interest_time==7
	replace lower_limit3 = ln((140- `omegabc2')/((1+interest_time)*10-  `omegabc2'))*0.9999 if interest_time==39

	gen upper_limit3 = ln((150- `omegabc2')/((1+interest_time)*0- `omegabc2'))


	
*****************************************************************	
*****************************************************************
*** FOR EXPONENTIAL UTILITY
*****************************************************************
*****************************************************************

** generate variables for estimation
	gen depvar4= time - ((1+interest_time)*(150-time))

** generate limits for tobit
	gen lower_limit4 =  0 - ((1+interest_time)*150) if interest_time <3
	replace lower_limit4 = 50 - ((1+interest_time)*100) if interest_time==3
	replace lower_limit4 = 100 - ((1+interest_time)*150) if interest_time==7
	replace lower_limit4 = 140 - ((1+interest_time)*10) if interest_time==39

	gen upper_limit4 = 150
	
	replace lower_limit4=-1500 if ra==1  //Avoids error of observations with ll() > ul() not allowed when running m24ts
//
	



***********************************************************************************************
***********************************************************************************************
***********************************************************************************************
****Tobit to cluster standard errors at the session/bin level

// Column 2
eststo m6ts: tobit depvar ln_1_r no_check days  if interest_time<3 & inst==0  & map_id==., ll(lower_limit) ul(upper_limit) nocons vce(cluster session_number)
nlcom (alpha_m6ts: (1/_b[ln_1_r]) +1) (delta_m6ts: exp(_b[days]/_b[ln_1_r])) ///
(annual_discount_m6ts: (1/(exp(_b[days]/_b[ln_1_r])))^365-1) ///
(P_no_check_m6ts:exp(_b[no_check]/_b[ln_1_r])), post


// Column 1
eststo m7ts: tobit depvar days ln_1_r no_check if interest_time<3 & inst==1 & map_id==., ll(lower_limit) ul(upper_limit) nocons vce(cluster session_number)
nlcom (alpha_m7ts: (1/_b[ln_1_r]) +1) (delta_m7ts: exp(_b[days]/_b[ln_1_r])) ///
(annual_discount_m7ts: (1/(exp(_b[days]/_b[ln_1_r])))^365-1) ///
(P_no_check_m7ts:exp(_b[no_check]/_b[ln_1_r])), post
test _b[P_no_check_m7ts]=.3238253

/* test _b[P_no_check_m7ts]=.3238253

 ( 1)  P_no_check_m7ts = .3238253

           chi2(  1) =    1.55
         Prob > chi2 =    0.2129 */

// Column 4
eststo m18ts: tobit depvar3 ln_1_r no_check days  if interest_time<3 & inst==0 & map_id==., ll(lower_limit3) ul(upper_limit3) nocons vce(cluster session_number)
nlcom (alpha_m18ts: (1/_b[ln_1_r]) +1) (delta_m18ts: exp(_b[days]/_b[ln_1_r])) ///
(annual_discount_m18ts: (1/(exp(_b[days]/_b[ln_1_r])))^365-1) ///
(P_no_check_m18ts:exp(_b[no_check]/_b[ln_1_r])), post


// Column 3
eststo m19ts: tobit depvar3 days ln_1_r no_check if interest_time<3 & inst==1 & map_id==. , ll(lower_limit3) ul(upper_limit3) nocons vce(cluster session_number)
nlcom (alpha_m19ts: (1/_b[ln_1_r]) +1) (delta_m19ts: exp(_b[days]/_b[ln_1_r])) ///
(annual_discount_m19ts: (1/(exp(_b[days]/_b[ln_1_r])))^365-1) ///
(P_no_check_m19ts:exp(_b[no_check]/_b[ln_1_r])), post
test _b[P_no_check_m19ts]= .4418573 

/*test _b[P_no_check_m19ts]= .4418573 

 ( 1)  P_no_check_m19ts = .4418573

           chi2(  1) =    1.41
         Prob > chi2 =    0.2354 */
		 
// Column 6
eststo m24ts: tobit depvar4 ln_1_r no_check days  if interest_time<3 & inst==0 & map_id==. & ra==0, ll(lower_limit4) ul(upper_limit4) nocons vce(cluster session_number)
nlcom (rho_m24ts:(-1/_b[ln_1_r])) (delta_m24ts:exp(_b[days]/_b[ln_1_r])) ///
(annual_discount_m24ts:(1/(exp(_b[days]/_b[ln_1_r]))^365-1)) ///
(P_no_check_m24ts:exp(_b[no_check]/_b[ln_1_r])), post

 
// Column 5
eststo m25ts: tobit depvar4 ln_1_r no_check  days  if interest_time<3 & inst==1 &map_id==., ll(lower_limit4) ul(upper_limit4) nocons vce(cluster session_number)
nlcom (rho_m25ts:(-1/_b[ln_1_r])) (delta_m25ts:exp(_b[days]/_b[ln_1_r])) ///
(annual_discount_m25ts:(1/(exp(_b[days]/_b[ln_1_r]))^365-1)) ///
(P_no_check_m25ts:exp(_b[no_check]/_b[ln_1_r])), post
test _b[P_no_check_m25ts]= .5242353
/*test _b[P_no_check_m25ts]= .5242353

 ( 1)  P_no_check_m25ts = .5242353

           chi2(  1) =    1.40
         Prob > chi2 =    0.2359
*/

**********************************************END OF TABLE 5**********************************


****************************************************************TABLE 6*************************************************************
**** Joint Estimation MPL, CLUSTERING AT SESSION LEVEL **********************************************************************************

** Omega=-0.01

global omega=-0.01






******************************Clustering at the Session/Bin level**********************************

*NWTF Column 1

ml model lf ML_crra_joint_mpl (alpha: mpl_risk mpl_time days interest_time interest_risk check ra prob const_a = ) (delta: ) (P: ) if treatment_inst=="Project Dungganon" & map_id==., cluster(session_number) missing  maximize technique(dfp) difficult trace showtolerance   init(0.30 0.98 0.50, copy)
ml display
estimates store mplnwtfS
di [P]_cons
test [P]_cons= .43687646  
/*[P]_cons = .4368765

           chi2(  1) =    0.07
         Prob > chi2 =    0.7900
*/




*ML Column 2

ml model lf ML_crra_joint_mpl (alpha: mpl_risk mpl_time days interest_time interest_risk check ra prob const_a = ) (delta: ) (P: ) if treatment_inst!="Project Dungganon" & map_id==. , cluster(session_number) missing  maximize technique(dfp) difficult trace showtolerance   init(0.30 0.98 0.50, copy)
estimates store mplml
di [P]_cons

ml display



** Omega=-50.25

global omega=-50.25



*NWTF Column 3

ml model lf ML_crra_joint_mpl (alpha: mpl_risk mpl_time days interest_time interest_risk check ra prob const_a = ) (delta: ) (P: ) if treatment_inst=="Project Dungganon" & map_id==. , cluster(session_number) missing  maximize technique(dfp) difficult trace showtolerance   init(0.30 0.98 0.50, copy)
ml display
di [P]_cons
test [P]_cons=.10264975

/*[P]_cons = .1026497

           chi2(  1) =    0.50
         Prob > chi2 =    0.4779
*/
*ML Column 4

ml model lf ML_crra_joint_mpl (alpha: mpl_risk mpl_time days interest_time interest_risk check ra prob const_a = ) (delta: ) (P: ) if treatment_inst!="Project Dungganon" & map_id==., cluster(session_number) missing  maximize technique(dfp) difficult trace showtolerance   init(0.30 0.98 0.50, copy)
di [P]_cons
ml display



********************************************************************************************************
******* SPECIFICATION 2: MULTIPLE PRICE LIST ************************************************************
***********CARA ESTIMATION********wit standard errors clustered at session/bin level********************
********************************************************************************************************

********************************************************************************************************
**** Joint Estimation :::::::****************************************************************************

 global omega=0
 
** CARA


*NWTF Column 5

ml model lf ML_cara_joint_mpl (rho: mpl_risk mpl_time days interest_time interest_risk check ra prob const_a = ) (delta: ) (P: ) if treatment_inst=="Project Dungganon" & map_id==. , cluster(session_number) missing  maximize technique(dfp) difficult trace showtolerance   init(0.005 0.98 0.50, copy)
ml display
di [P]_cons //.56713927
test [P]_cons=.5167679
/* [P]_cons = .5167679

           chi2(  1) =    0.04
         Prob > chi2 =    0.8422

. 
*/

*ML Column 6

ml model lf ML_cara_joint_mpl (rho: mpl_risk mpl_time days interest_time interest_risk check ra prob const_a = ) (delta: ) (P: ) if treatment_inst!="Project Dungganon" & map_id==., cluster(session_number) missing  maximize technique(dfp) difficult trace showtolerance   init(0.005 0.98 0.50, copy)
ml display
di [P]_cons 

*****************************************************************END OF TABLE 6**************************************************************************************************************




**************************************************************************************************************************************************************************************************
************Table 9: CT TRANSFORMATION***************************************************************************************************************************




*Implementing linear transformation of decisions for a=50, 100, 140.

gen time_a = time - (150-time)/2 if interest==3 & ra==0
replace time_a =time - 2*(150-time) if interest==7 & ra==0
replace time_a = time - 14*(150-time) if interest==39 & ra==0
replace time_a = time if interest<3 & ra==0


	collapse (mean) time mpl_time time_a, by(treatment_inst interest days check)
	drop if check==.
	
	
	preserve
	keep if treatment_inst=="Project Dungganon" & check==1
	rename time time_cknwtf
	rename mpl_time mpltime_cknwtf
	rename time_a timea_cknwtf
		sort days check interest
	save "$WORKING_ANALYSIS\ctratio_NWTFcheck.dta", replace
	restore
	
	
	preserve
	keep if treatment_inst!="Project Dungganon" & check==1
	rename time time_ckml
	rename mpl_time mpltime_ckml
	rename time_a timea_ckml
		sort days check interest
	save "$WORKING_ANALYSIS\ctratio_MLcheck.dta", replace
	restore
	

	use "$WORKING_ANALYSIS\ctratio_MLcheck.dta", clear
	use "$WORKING_ANALYSIS\ctratio_NWTFcheck.dta", clear
	
	use "$WORKING_ANALYSIS\games_time_and_risk_longS.dta", clear
	

	merge m:m days check interest using "$WORKING_ANALYSIS\ctratio_NWTFcheck.dta"
	

drop _merge
merge m:m days check interest using "$WORKING_ANALYSIS\ctratio_MLcheck.dta"


drop _merge




drop if map_id!=. 

gen time_ckdiff=time_ckml-time_cknwtf
gen time2=time

replace time2=time-time_ckdiff if treatment_inst=="Money Lender" & check==1


replace time2=0 if treatment_inst=="Money Lender" & check==1 & time2<0

	
bys interest: sum time2 if check==1 & inst==0
bys interest: sum time2 if check==1 & inst==1
	
	preserve
	keep if treatment_inst!="Project Dungganon" & check==1
	collapse (mean) time2, by(treatment_inst interest days check)
	drop if check==.
	rename time2 time_ckml2
		sort days check interest
	save "$WORKING_ANALYSIS\ctratio_MLcheck2.dta", replace
	restore	
	

	
merge m:m days check interest using "$WORKING_ANALYSIS\ctratio_MLcheck2.dta"


drop _merge		
	
bys interest: sum time_ckml2 if check==1 & inst==0

gen time_ckdiff2=time_ckml2-time_cknwtf
bys interest: sum time_ckdiff2 if check==1
gen time3=time2

replace time3=time2-time_ckdiff2 if treatment_inst=="Money Lender" & check==1


replace time3=0 if treatment_inst=="Money Lender" & check==1 & time3<0	


bys interest: sum time3 if check==1 & inst==0
bys interest: sum time3 if check==1 & inst==1


bys inst: sum time3 if check==1 & interest<3
	
	
preserve
	keep if treatment_inst!="Project Dungganon" & check==1
	collapse (mean) time3, by(treatment_inst interest days check)
	drop if check==.
	rename time3 time_ckml3
		sort days check interest
	save "$WORKING_ANALYSIS\ctratio_MLcheck3.dta", replace
	restore	

		
merge m:m days check interest using "$WORKING_ANALYSIS\ctratio_MLcheck3.dta"


drop _merge		
	
bys interest: sum time_ckml3 if check==1 & inst==0



gen time_ckdiff3=time_ckml3-time_cknwtf
bys interest: sum time_ckdiff3 if check==1
gen time4=time3

replace time4=time3-time_ckdiff3 if treatment_inst=="Money Lender" & check==1

replace time4=0 if treatment_inst=="Money Lender" & check==1 & time4<0	
	

	
	bys interest: sum time4 if check==1 & inst==0
bys interest: sum time4 if check==1 & inst==1


bys inst: sum time4 if check==1 & interest<3
	


************

xtset subid


** define outside consumption
	local omega = -0.01

** generate variables for estimation

    gen depvar4 = ln((time4 - `omega') / ((1+interest)*(150-time4) - `omega')) if ra==0

	gen ln_1_r = ln(1+interest) if ra==0

** treatment dummies
	gen no_check = 1-check if ra==0

** generate limits for tobit
	gen lower_limit =     ln((0-   `omega')/((1+interest)*150- `omega'))*0.9999 if interest <3 & ra==0
	replace lower_limit = ln((50-  `omega')/((1+interest)*100- `omega'))*0.9999 if interest==3 & ra==0
	replace lower_limit = ln((100- `omega')/((1+interest)*50-  `omega'))*0.9999 if interest==7 & ra==0
	replace lower_limit = ln((140- `omega')/((1+interest)*10-  `omega'))*0.9999 if interest==39 & ra==0

	gen upper_limit = ln((150- `omega')/((1+interest)*0- `omega')) if ra==0


gen inst_check=inst*no_check if ra==0



	gen back_cons_mod=back_cons
	replace back_cons_mod=back_cons_hh/hh_size if back_cons==0
	sum back_cons_mod

	gen back_cons_mod2=back_cons
	replace back_cons_mod2=back_cons_hh/hh_size if back_cons<back_cons_hh

	gen back_cons_mod_daily=back_cons_mod/7


	sum back_cons_mod_daily
		local omegabc2 = -r(mean)
		di `omegabc2'

	** generate variables for estimation
		gen depvar3x = ln((time4 - `omegabc2') / ((1+interest)*(150-time4) - `omegabc2')) if ra==0

	** generate limits for tobit

		gen lower_limit3 =     ln((0-   `omegabc2')/((1+interest)*150- `omegabc2'))*0.9999 if interest <3 & ra==0
		replace lower_limit3 = ln((50-  `omegabc2')/((1+interest)*100- `omegabc2'))*0.9999 if interest==3 & ra==0
		replace lower_limit3 = ln((100- `omegabc2')/((1+interest)*50-  `omegabc2'))*0.9999 if interest==7 & ra==0
		replace lower_limit3 = ln((140- `omegabc2')/((1+interest)*10-  `omegabc2'))*0.9999 if interest==39 & ra==0

		gen upper_limit3 = ln((150- `omegabc2')/((1+interest)*0- `omegabc2')) if ra==0



	** generate variables for estimation
		gen depvar4x= time4 - ((1+interest)*(150-time4)) if ra==0

	** generate limits for tobit

		gen lower_limit4 =  0 - ((1+interest)*150) if interest <3 & ra==0
		replace lower_limit4 = 50 - ((1+interest)*100) if interest==3 & ra==0
		replace lower_limit4 = 100 - ((1+interest)*150) if interest==7 & ra==0
		replace lower_limit4 = 140 - ((1+interest)*10) if interest==39 & ra==0

		gen upper_limit4 = 150 if ra==0
		
// Column 1		
		eststo m7mlt: tobit depvar4 ln_1_r no_check days  if interest<3 & inst==0  & ra==0, ll(lower_limit) ul(upper_limit) nocons vce(cluster session_number)
	nlcom (alpha_m7mlt: (1/_b[ln_1_r]) +1) (delta_m7mlt: exp(_b[days]/_b[ln_1_r])) ///
	(annual_discount_m7mlt: (1/(exp(_b[days]/_b[ln_1_r])))^365-1) ///
	(P_no_check_m7mlt:exp(_b[no_check]/_b[ln_1_r])), post	
// Column 2	
	eststo m19mlt: tobit depvar3x ln_1_r no_check days  if interest<3 & inst==0  & ra==0 , ll(lower_limit3) ul(upper_limit3) nocons vce(cluster session_number)
	nlcom (alpha_m19mlt: (1/_b[ln_1_r]) +1) (delta_m19mlt: exp(_b[days]/_b[ln_1_r])) ///
	(annual_discount_m19mlt: (1/(exp(_b[days]/_b[ln_1_r])))^365-1) ///
	(P_no_check_m19mlt:exp(_b[no_check]/_b[ln_1_r])), post
	
// Column 3		
	eststo m24mlt: tobit depvar4x ln_1_r no_check days  if interest<3 & inst==0 & ra==0, ll(lower_limit4) ul(upper_limit4) nocons vce(cluster session_number)
	nlcom (rho_m24mlt:(-1/_b[ln_1_r])) (delta_m24mlt:exp(_b[days]/_b[ln_1_r])) ///
	(annual_discount_m24mlt:(1/(exp(_b[days]/_b[ln_1_r]))^365-1)) ///
	(P_no_check_m24mlt:exp(_b[no_check]/_b[ln_1_r])), post

	
**********************************Table 14*********************************************************************************************

use "$WORKING_ANALYSIS\games_time_and_risk_longS.dta", clear
	

tab time interest1 if map_id==., column nofreq 

/*
Lower-Bound: 
 payment   |                                             interest1
     today |         1   1.333333   1.666667          2   2.333333   2.666667          4          8         40 |    
-----------+---------------------------------------------------------------------------------------------------+----------
         0 |     21.52      24.36      24.63      25.39      25.48      26.97       0.00       0.00       0.00 |    		 
        50 |     -                                                                 41.61                       |     
       100 |                                                                                  58.01            |    
       140 |                                                                                             60.18 |  
Upper-Bound:	   
	   150 |     33.78      25.55      23.65      21.43      20.47      19.44      18.60      17.38      15.94 |    
   
Interior: 100 - (Proportion of Lower-Bound choices) - (Proportion of Upper-Bound choices) */	
**********************************Table 15*********************************************************************************************
eststo clear
sort check
	eststo: estpost ttest time if map_id==., by(check_first) //Check vs No Check
eststo: estpost ttest time if map_id==. & treatment_inst=="Project Dungganon", by(check_first) 
eststo: estpost ttest time if map_id==. & treatment_inst=="Money Lender", by(check_first) 
	esttab using "$WORKING_ANALYSIS\Table15.tex", replace se label title(Equality of Means Test: No-Check vs Check\label{tab1}) mtitles ("All" "NWTF" "ML") star (* 0.10 ** 0.05 *** 0.01)
*****************************	
	
	
	

**********************************Table 16*********************************************************************************************
gen inst2=1-inst	
eststo T16c1: reg time check_first if map_id==., cluster(session_number)
eststo T16c2: reg time check_first inst2 if map_id==., cluster(session_number)
eststo T16c3: reg time check_first##inst2 if map_id==., cluster(session_number)

esttab T16c1 T16c2 T16c3 using "$WORKING_ANALYSIS\Table 16.tex", replace se scalars(r2 N) title(Order Effects\label{order})  star (* 0.10 ** 0.05 *** 0.01) addnotes("Clustered standard errors at the session level")

